jactorch.nn.residual
====================

.. automodule:: jactorch.nn.residual

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      ResidualConvBlock
      ResidualConvBottleneck
      ResidualGRU
      ResidualLinear
   
   

   
   
   

   
   
   








.. rubric:: Class ResidualConvBlock
.. autoclass:: ResidualConvBlock
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ResidualConvBottleneck
.. autoclass:: ResidualConvBottleneck
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ResidualGRU
.. autoclass:: ResidualGRU
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ResidualLinear
.. autoclass:: ResidualLinear
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







